==> zio-streams-compress-core_3-0.0.1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"zio-streams-compress-core","t":"zio-streams-compress-core","d":"","k":"static","x":""},
{"l":"zio/compress.html#","e":false,"i":"","n":"zio.compress","t":"zio.compress","d":"","k":"package","x":""},
{"l":"zio/compress/ArchiveEntry.html#","e":false,"i":"","n":"ArchiveEntry","t":"ArchiveEntry[+Size <: (Option), +Underlying](name: String, uncompressedSize: Size[Long], isDirectory: Boolean, lastModified: Option[Instant], lastAccess: Option[Instant], creation: Option[Instant], underlying: Underlying)","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/ArchiveEntry.html#underlying-fffff1c2","e":false,"i":"","n":"underlying","t":"underlying[U](implicit U: ArchiveEntryToUnderlying[U]): U","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry.html#withIsDirectory-fffff04e","e":false,"i":"","n":"withIsDirectory","t":"withIsDirectory(isDirectory: Boolean): ArchiveEntry[Size, Underlying]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry.html#withLastModified-411","e":false,"i":"","n":"withLastModified","t":"withLastModified(lastModified: Option[Instant]): ArchiveEntry[Size, Underlying]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry.html#withName-e9","e":false,"i":"","n":"withName","t":"withName(name: String): ArchiveEntry[Size, Underlying]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry.html#withUncompressedSize-e80","e":false,"i":"","n":"withUncompressedSize","t":"withUncompressedSize[S <: (Option)](uncompressedSize: S[Long]): ArchiveEntry[S, Underlying]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry.html#withUnderlying-fffff86a","e":false,"i":"","n":"withUnderlying","t":"withUnderlying[U](underlying: U): ArchiveEntry[Size, U]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry$.html#","e":false,"i":"","n":"ArchiveEntry","t":"ArchiveEntry","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ArchiveEntry$.html#fromUnderlying-fffff524","e":false,"i":"","n":"fromUnderlying","t":"fromUnderlying[Size <: (Option), U](underlying: U)(implicit U: ArchiveEntryFromUnderlying[Size, U]): ArchiveEntry[Option, U]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry$$ArchiveEntryFromUnderlying.html#","e":false,"i":"","n":"ArchiveEntryFromUnderlying","t":"ArchiveEntryFromUnderlying[+Size <: (Option), Underlying]","d":"zio.compress.ArchiveEntry","k":"trait","x":""},
{"l":"zio/compress/ArchiveEntry$$ArchiveEntryFromUnderlying.html#archiveEntry-d7b","e":false,"i":"","n":"archiveEntry","t":"archiveEntry(underlying: Underlying): ArchiveEntry[Size, Underlying]","d":"zio.compress.ArchiveEntry.ArchiveEntryFromUnderlying","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry$$ArchiveEntryToUnderlying.html#","e":false,"i":"","n":"ArchiveEntryToUnderlying","t":"ArchiveEntryToUnderlying[+Underlying]","d":"zio.compress.ArchiveEntry","k":"trait","x":""},
{"l":"zio/compress/ArchiveEntry$$ArchiveEntryToUnderlying.html#underlying-dc3","e":false,"i":"","n":"underlying","t":"underlying[S <: (Option)](entry: ArchiveEntry[S, Any], underlying: Any): Underlying","d":"zio.compress.ArchiveEntry.ArchiveEntryToUnderlying","k":"def","x":""},
{"l":"zio/compress/ArchiveSingleFileCompressor.html#","e":false,"i":"","n":"ArchiveSingleFileCompressor","t":"ArchiveSingleFileCompressor[Size <: (Option)] extends Compressor","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/ArchiveSingleFileCompressor$.html#","e":false,"i":"","n":"ArchiveSingleFileCompressor","t":"ArchiveSingleFileCompressor","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ArchiveSingleFileCompressor$.html#apply-fffffa1e","e":false,"i":"","n":"apply","t":"apply[Size <: (Option)](archiver: Archiver[Size], entry: ArchiveEntry[Size, Any]): ArchiveSingleFileCompressor[Size]","d":"zio.compress.ArchiveSingleFileCompressor","k":"def","x":""},
{"l":"zio/compress/ArchiveSingleFileCompressor$.html#forName-fffffc40","e":false,"i":"","n":"forName","t":"forName(archiver: Archiver[Option], name: String): ArchiveSingleFileCompressor[Option]","d":"zio.compress.ArchiveSingleFileCompressor","k":"def","x":""},
{"l":"zio/compress/ArchiveSingleFileCompressor$.html#forName-ac4","e":false,"i":"","n":"forName","t":"forName(archiver: Archiver[Some], name: String, size: Long): ArchiveSingleFileCompressor[Some]","d":"zio.compress.ArchiveSingleFileCompressor","k":"def","x":""},
{"l":"zio/compress/ArchiveSingleFileDecompressor.html#","e":false,"i":"","n":"ArchiveSingleFileDecompressor","t":"ArchiveSingleFileDecompressor[Size <: (Option), Underlying] extends Decompressor","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/ArchiveSingleFileDecompressor$.html#","e":false,"i":"","n":"ArchiveSingleFileDecompressor","t":"ArchiveSingleFileDecompressor","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ArchiveSingleFileDecompressor$.html#apply-983","e":false,"i":"","n":"apply","t":"apply[Size <: (Option), Underlying](unarchiver: Unarchiver[Size, Underlying]): ArchiveSingleFileDecompressor[Size, Underlying]","d":"zio.compress.ArchiveSingleFileDecompressor","k":"def","x":""},
{"l":"zio/compress/Archiver.html#","e":false,"i":"","n":"Archiver","t":"Archiver[-Size <: (Option)]","d":"zio.compress","k":"trait","x":""},
{"l":"zio/compress/Archiver.html#archive-0","e":false,"i":"","n":"archive","t":"archive: ZPipeline[Any, Throwable, (ArchiveEntry[Size, Any], ZStream[Any, Throwable, Byte]), Byte]","d":"zio.compress.Archiver","k":"def","x":""},
{"l":"zio/compress/Archiver$.html#","e":false,"i":"","n":"Archiver","t":"Archiver","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/Archiver$.html#checkUncompressedSize-fffff6ed","e":false,"i":"","n":"checkUncompressedSize","t":"checkUncompressedSize[Size <: (Option)]: ZPipeline[Any, Throwable, (ArchiveEntry[Size, Any], ZStream[Any, Throwable, Byte]), (ArchiveEntry[Size, Any], ZStream[Any, Throwable, Byte])]","d":"zio.compress.Archiver","k":"def","x":""},
{"l":"zio/compress/Compressor.html#","e":false,"i":"","n":"Compressor","t":"Compressor","d":"zio.compress","k":"trait","x":""},
{"l":"zio/compress/Compressor.html#compress-0","e":false,"i":"","n":"compress","t":"compress: ZPipeline[Any, Throwable, Byte, Byte]","d":"zio.compress.Compressor","k":"def","x":""},
{"l":"zio/compress/Compressor$.html#","e":false,"i":"","n":"Compressor","t":"Compressor","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/Compressor$.html#empty-0","e":false,"i":"","n":"empty","t":"empty: Compressor","d":"zio.compress.Compressor","k":"def","x":""},
{"l":"zio/compress/Decompressor.html#","e":false,"i":"","n":"Decompressor","t":"Decompressor","d":"zio.compress","k":"trait","x":""},
{"l":"zio/compress/Decompressor.html#decompress-0","e":false,"i":"","n":"decompress","t":"decompress: ZPipeline[Any, Throwable, Byte, Byte]","d":"zio.compress.Decompressor","k":"def","x":""},
{"l":"zio/compress/Decompressor$.html#","e":false,"i":"","n":"Decompressor","t":"Decompressor","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/Decompressor$.html#empty-0","e":false,"i":"","n":"empty","t":"empty: Decompressor","d":"zio.compress.Decompressor","k":"def","x":""},
{"l":"zio/compress/Defaults$.html#","e":false,"i":"","n":"Defaults","t":"Defaults","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/Defaults$.html#DefaultChunkSize-0","e":false,"i":"","n":"DefaultChunkSize","t":"DefaultChunkSize: Int","d":"zio.compress.Defaults","k":"val","x":""},
{"l":"zio/compress/Defaults$.html#DefaultChunkedQueueSize-0","e":false,"i":"","n":"DefaultChunkedQueueSize","t":"DefaultChunkedQueueSize: Int","d":"zio.compress.Defaults","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel.html#","e":false,"i":"","n":"DeflateCompressionLevel","t":"DeflateCompressionLevel","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#","e":false,"i":"","n":"DeflateCompressionLevel","t":"DeflateCompressionLevel","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#BestCompressionLevel-0","e":false,"i":"","n":"BestCompressionLevel","t":"BestCompressionLevel: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel0-0","e":false,"i":"","n":"CompressionLevel0","t":"CompressionLevel0: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel1-0","e":false,"i":"","n":"CompressionLevel1","t":"CompressionLevel1: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel2-0","e":false,"i":"","n":"CompressionLevel2","t":"CompressionLevel2: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel3-0","e":false,"i":"","n":"CompressionLevel3","t":"CompressionLevel3: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel4-0","e":false,"i":"","n":"CompressionLevel4","t":"CompressionLevel4: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel5-0","e":false,"i":"","n":"CompressionLevel5","t":"CompressionLevel5: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel6-0","e":false,"i":"","n":"CompressionLevel6","t":"CompressionLevel6: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel7-0","e":false,"i":"","n":"CompressionLevel7","t":"CompressionLevel7: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel8-0","e":false,"i":"","n":"CompressionLevel8","t":"CompressionLevel8: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel9-0","e":false,"i":"","n":"CompressionLevel9","t":"CompressionLevel9: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#DefaultCompressionLevel-0","e":false,"i":"","n":"DefaultCompressionLevel","t":"DefaultCompressionLevel: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#FastestCompressionLevel-0","e":false,"i":"","n":"FastestCompressionLevel","t":"FastestCompressionLevel: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#NoCompressionLevel-0","e":false,"i":"","n":"NoCompressionLevel","t":"NoCompressionLevel: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#apply-fffff2e4","e":false,"i":"","n":"apply","t":"apply(level: Int): Option[DeflateCompressionLevel]","d":"zio.compress.DeflateCompressionLevel","k":"def","x":""},
{"l":"zio/compress/Unarchiver.html#","e":false,"i":"","n":"Unarchiver","t":"Unarchiver[Size <: (Option), Underlying]","d":"zio.compress","k":"trait","x":""},
{"l":"zio/compress/Unarchiver.html#unarchive-0","e":false,"i":"","n":"unarchive","t":"unarchive: ZPipeline[Any, Throwable, Byte, (ArchiveEntry[Size, Underlying], ZStream[Any, Throwable, Byte])]","d":"zio.compress.Unarchiver","k":"def","x":""}];

==> zio-streams-compress-core_3-1.0.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"zio-streams-compress-core","t":"zio-streams-compress-core","d":"","k":"static","x":""},
{"l":"zio/compress.html#","e":false,"i":"","n":"zio.compress","t":"zio.compress","d":"","k":"package","x":""},
{"l":"zio/compress/ArchiveEntry.html#","e":false,"i":"","n":"ArchiveEntry","t":"ArchiveEntry[+Size <: (Option), +Underlying](name: String, uncompressedSize: Size[Long], isDirectory: Boolean, lastModified: Option[Instant], lastAccess: Option[Instant], creation: Option[Instant], underlying: Underlying)","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/ArchiveEntry.html#underlying-fffff1c2","e":false,"i":"","n":"underlying","t":"underlying[U](implicit U: ArchiveEntryToUnderlying[U]): U","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry.html#withIsDirectory-fffff04e","e":false,"i":"","n":"withIsDirectory","t":"withIsDirectory(isDirectory: Boolean): ArchiveEntry[Size, Underlying]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry.html#withLastModified-411","e":false,"i":"","n":"withLastModified","t":"withLastModified(lastModified: Option[Instant]): ArchiveEntry[Size, Underlying]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry.html#withName-e9","e":false,"i":"","n":"withName","t":"withName(name: String): ArchiveEntry[Size, Underlying]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry.html#withUncompressedSize-e80","e":false,"i":"","n":"withUncompressedSize","t":"withUncompressedSize[S <: (Option)](uncompressedSize: S[Long]): ArchiveEntry[S, Underlying]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry.html#withUnderlying-fffff86a","e":false,"i":"","n":"withUnderlying","t":"withUnderlying[U](underlying: U): ArchiveEntry[Size, U]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry$.html#","e":false,"i":"","n":"ArchiveEntry","t":"ArchiveEntry","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ArchiveEntry$.html#fromUnderlying-fffff524","e":false,"i":"","n":"fromUnderlying","t":"fromUnderlying[Size <: (Option), U](underlying: U)(implicit U: ArchiveEntryFromUnderlying[Size, U]): ArchiveEntry[Option, U]","d":"zio.compress.ArchiveEntry","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry$$ArchiveEntryFromUnderlying.html#","e":false,"i":"","n":"ArchiveEntryFromUnderlying","t":"ArchiveEntryFromUnderlying[+Size <: (Option), Underlying] extends Serializable","d":"zio.compress.ArchiveEntry","k":"trait","x":""},
{"l":"zio/compress/ArchiveEntry$$ArchiveEntryFromUnderlying.html#archiveEntry-d7b","e":false,"i":"","n":"archiveEntry","t":"archiveEntry(underlying: Underlying): ArchiveEntry[Size, Underlying]","d":"zio.compress.ArchiveEntry.ArchiveEntryFromUnderlying","k":"def","x":""},
{"l":"zio/compress/ArchiveEntry$$ArchiveEntryToUnderlying.html#","e":false,"i":"","n":"ArchiveEntryToUnderlying","t":"ArchiveEntryToUnderlying[+Underlying] extends Serializable","d":"zio.compress.ArchiveEntry","k":"trait","x":""},
{"l":"zio/compress/ArchiveEntry$$ArchiveEntryToUnderlying.html#underlying-dc3","e":false,"i":"","n":"underlying","t":"underlying[S <: (Option)](entry: ArchiveEntry[S, Any], underlying: Any): Underlying","d":"zio.compress.ArchiveEntry.ArchiveEntryToUnderlying","k":"def","x":""},
{"l":"zio/compress/ArchiveSingleFileCompressor.html#","e":false,"i":"","n":"ArchiveSingleFileCompressor","t":"ArchiveSingleFileCompressor[Size <: (Option)] extends Compressor","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/ArchiveSingleFileCompressor$.html#","e":false,"i":"","n":"ArchiveSingleFileCompressor","t":"ArchiveSingleFileCompressor","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ArchiveSingleFileCompressor$.html#apply-fffffa1e","e":false,"i":"","n":"apply","t":"apply[Size <: (Option)](archiver: Archiver[Size], entry: ArchiveEntry[Size, Any]): ArchiveSingleFileCompressor[Size]","d":"zio.compress.ArchiveSingleFileCompressor","k":"def","x":""},
{"l":"zio/compress/ArchiveSingleFileCompressor$.html#forName-fffffc40","e":false,"i":"","n":"forName","t":"forName(archiver: Archiver[Option], name: String): ArchiveSingleFileCompressor[Option]","d":"zio.compress.ArchiveSingleFileCompressor","k":"def","x":""},
{"l":"zio/compress/ArchiveSingleFileCompressor$.html#forName-ac4","e":false,"i":"","n":"forName","t":"forName(archiver: Archiver[Some], name: String, size: Long): ArchiveSingleFileCompressor[Some]","d":"zio.compress.ArchiveSingleFileCompressor","k":"def","x":""},
{"l":"zio/compress/ArchiveSingleFileDecompressor.html#","e":false,"i":"","n":"ArchiveSingleFileDecompressor","t":"ArchiveSingleFileDecompressor[Size <: (Option), Underlying] extends Decompressor","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/ArchiveSingleFileDecompressor$.html#","e":false,"i":"","n":"ArchiveSingleFileDecompressor","t":"ArchiveSingleFileDecompressor","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/ArchiveSingleFileDecompressor$.html#apply-983","e":false,"i":"","n":"apply","t":"apply[Size <: (Option), Underlying](unarchiver: Unarchiver[Size, Underlying]): ArchiveSingleFileDecompressor[Size, Underlying]","d":"zio.compress.ArchiveSingleFileDecompressor","k":"def","x":""},
{"l":"zio/compress/Archiver.html#","e":false,"i":"","n":"Archiver","t":"Archiver[-Size <: (Option)] extends Serializable","d":"zio.compress","k":"trait","x":""},
{"l":"zio/compress/Archiver.html#archive-b4f","e":false,"i":"","n":"archive","t":"archive(implicit trace: Trace): ZPipeline[Any, Throwable, (ArchiveEntry[Size, Any], ZStream[Any, Throwable, Byte]), Byte]","d":"zio.compress.Archiver","k":"def","x":""},
{"l":"zio/compress/Archiver$.html#","e":false,"i":"","n":"Archiver","t":"Archiver","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/Archiver$.html#checkUncompressedSize-fffff6ed","e":false,"i":"","n":"checkUncompressedSize","t":"checkUncompressedSize[Size <: (Option)]: ZPipeline[Any, Throwable, (ArchiveEntry[Size, Any], ZStream[Any, Throwable, Byte]), (ArchiveEntry[Size, Any], ZStream[Any, Throwable, Byte])]","d":"zio.compress.Archiver","k":"def","x":""},
{"l":"zio/compress/Compressor.html#","e":false,"i":"","n":"Compressor","t":"Compressor extends Serializable","d":"zio.compress","k":"trait","x":""},
{"l":"zio/compress/Compressor.html#compress-b4f","e":false,"i":"","n":"compress","t":"compress(implicit trace: Trace): ZPipeline[Any, Throwable, Byte, Byte]","d":"zio.compress.Compressor","k":"def","x":""},
{"l":"zio/compress/Compressor$.html#","e":false,"i":"","n":"Compressor","t":"Compressor extends Serializable","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/Compressor$.html#empty-0","e":false,"i":"","n":"empty","t":"empty: Compressor","d":"zio.compress.Compressor","k":"def","x":""},
{"l":"zio/compress/Decompressor.html#","e":false,"i":"","n":"Decompressor","t":"Decompressor extends Serializable","d":"zio.compress","k":"trait","x":""},
{"l":"zio/compress/Decompressor.html#decompress-b4f","e":false,"i":"","n":"decompress","t":"decompress(implicit trace: Trace): ZPipeline[Any, Throwable, Byte, Byte]","d":"zio.compress.Decompressor","k":"def","x":""},
{"l":"zio/compress/Decompressor$.html#","e":false,"i":"","n":"Decompressor","t":"Decompressor","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/Decompressor$.html#empty-0","e":false,"i":"","n":"empty","t":"empty: Decompressor","d":"zio.compress.Decompressor","k":"def","x":""},
{"l":"zio/compress/Defaults$.html#","e":false,"i":"","n":"Defaults","t":"Defaults","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/Defaults$.html#DefaultChunkSize-0","e":false,"i":"","n":"DefaultChunkSize","t":"DefaultChunkSize: Int","d":"zio.compress.Defaults","k":"val","x":""},
{"l":"zio/compress/Defaults$.html#DefaultChunkedQueueSize-0","e":false,"i":"","n":"DefaultChunkedQueueSize","t":"DefaultChunkedQueueSize: Int","d":"zio.compress.Defaults","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel.html#","e":false,"i":"","n":"DeflateCompressionLevel","t":"DeflateCompressionLevel extends AnyVal","d":"zio.compress","k":"class","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#","e":false,"i":"","n":"DeflateCompressionLevel","t":"DeflateCompressionLevel","d":"zio.compress","k":"object","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#BestCompressionLevel-0","e":false,"i":"","n":"BestCompressionLevel","t":"BestCompressionLevel: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel0-0","e":false,"i":"","n":"CompressionLevel0","t":"CompressionLevel0: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel1-0","e":false,"i":"","n":"CompressionLevel1","t":"CompressionLevel1: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel2-0","e":false,"i":"","n":"CompressionLevel2","t":"CompressionLevel2: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel3-0","e":false,"i":"","n":"CompressionLevel3","t":"CompressionLevel3: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel4-0","e":false,"i":"","n":"CompressionLevel4","t":"CompressionLevel4: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel5-0","e":false,"i":"","n":"CompressionLevel5","t":"CompressionLevel5: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel6-0","e":false,"i":"","n":"CompressionLevel6","t":"CompressionLevel6: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel7-0","e":false,"i":"","n":"CompressionLevel7","t":"CompressionLevel7: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel8-0","e":false,"i":"","n":"CompressionLevel8","t":"CompressionLevel8: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#CompressionLevel9-0","e":false,"i":"","n":"CompressionLevel9","t":"CompressionLevel9: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#DefaultCompressionLevel-0","e":false,"i":"","n":"DefaultCompressionLevel","t":"DefaultCompressionLevel: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#FastestCompressionLevel-0","e":false,"i":"","n":"FastestCompressionLevel","t":"FastestCompressionLevel: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#NoCompressionLevel-0","e":false,"i":"","n":"NoCompressionLevel","t":"NoCompressionLevel: DeflateCompressionLevel","d":"zio.compress.DeflateCompressionLevel","k":"val","x":""},
{"l":"zio/compress/DeflateCompressionLevel$.html#apply-fffff2e4","e":false,"i":"","n":"apply","t":"apply(level: Int): Option[DeflateCompressionLevel]","d":"zio.compress.DeflateCompressionLevel","k":"def","x":""},
{"l":"zio/compress/Unarchiver.html#","e":false,"i":"","n":"Unarchiver","t":"Unarchiver[Size <: (Option), Underlying] extends Serializable","d":"zio.compress","k":"trait","x":""},
{"l":"zio/compress/Unarchiver.html#unarchive-b4f","e":false,"i":"","n":"unarchive","t":"unarchive(implicit trace: Trace): ZPipeline[Any, Throwable, Byte, (ArchiveEntry[Size, Underlying], ZStream[Any, Throwable, Byte])]","d":"zio.compress.Unarchiver","k":"def","x":""}];
